aboutsummaryrefslogtreecommitdiff
path: root/src/qt/guiutil.cpp
diff options
context:
space:
mode:
authorRoss Nicoll <[email protected]>2018-01-20 17:55:38 +0000
committerRoss Nicoll <[email protected]>2019-03-25 05:36:11 +0000
commit4a87b53e556e5f1ecfa53f606f9a26b50d2d6fea (patch)
tree0e0b1c7e38b695b677691459adc010d22d4e4aa1 /src/qt/guiutil.cpp
parentFix copyright substitution (diff)
downloaddiscoin-4a87b53e556e5f1ecfa53f606f9a26b50d2d6fea.tar.xz
discoin-4a87b53e556e5f1ecfa53f606f9a26b50d2d6fea.zip
Update QT client messages and translations to Doge equivalents (#1429)
Update QT client messages and translations to Doge equivalents.
Diffstat (limited to 'src/qt/guiutil.cpp')
-rw-r--r--src/qt/guiutil.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/qt/guiutil.cpp b/src/qt/guiutil.cpp
index 1fcfad253..6912b9312 100644
--- a/src/qt/guiutil.cpp
+++ b/src/qt/guiutil.cpp
@@ -125,7 +125,7 @@ void setupAddressWidget(QValidatedLineEdit *widget, QWidget *parent)
#if QT_VERSION >= 0x040700
// We don't want translators to use own addresses in translations
// and this is the only place, where this address is supplied.
- widget->setPlaceholderText(QObject::tr("Enter a Bitcoin address (e.g. %1)").arg(
+ widget->setPlaceholderText(QObject::tr("Enter a Dogecoin address (e.g. %1)").arg(
QString::fromStdString(DummyAddress(Params()))));
#endif
widget->setValidator(new BitcoinAddressEntryValidator(parent));
@@ -143,8 +143,8 @@ void setupAmountWidget(QLineEdit *widget, QWidget *parent)
bool parseBitcoinURI(const QUrl &uri, SendCoinsRecipient *out)
{
- // return if URI is not valid or is no bitcoin: URI
- if(!uri.isValid() || uri.scheme() != QString("bitcoin"))
+ // return if URI is not valid or is no dogecoin: URI
+ if(!uri.isValid() || uri.scheme() != QString("dogecoin"))
return false;
SendCoinsRecipient rv;
@@ -204,13 +204,13 @@ bool parseBitcoinURI(const QUrl &uri, SendCoinsRecipient *out)
bool parseBitcoinURI(QString uri, SendCoinsRecipient *out)
{
// Convert bitcoin:// to bitcoin:
//
// Cannot handle this later, because bitcoin:// will cause Qt to see the part after // as host,
// which will lower-case it (and thus invalidate the address).
- if(uri.startsWith("bitcoin://", Qt::CaseInsensitive))
+ if(uri.startsWith("dogecoin://", Qt::CaseInsensitive))
{
- uri.replace(0, 10, "bitcoin:");
+ uri.replace(0, 11, "dogecoin:");
}
QUrl uriInstance(uri);
return parseBitcoinURI(uriInstance, out);
@@ -218,7 +218,7 @@ bool parseBitcoinURI(QString uri, SendCoinsRecipient *out)
QString formatBitcoinURI(const SendCoinsRecipient &info)
{
- QString ret = QString("bitcoin:%1").arg(info.address);
+ QString ret = QString("dogecoin:%1").arg(info.address);
int paramCount = 0;
if (info.amount)
@@ -597,10 +597,10 @@ boost::filesystem::path static StartupShortcutPath()
{
std::string chain = ChainNameFromCommandLine();
if (chain == CBaseChainParams::MAIN)
- return GetSpecialFolderPath(CSIDL_STARTUP) / "Bitcoin.lnk";
+ return GetSpecialFolderPath(CSIDL_STARTUP) / "Dogecoin.lnk";
if (chain == CBaseChainParams::TESTNET) // Remove this special case when CBaseChainParams::TESTNET = "testnet4"
- return GetSpecialFolderPath(CSIDL_STARTUP) / "Bitcoin (testnet).lnk";
- return GetSpecialFolderPath(CSIDL_STARTUP) / strprintf("Bitcoin (%s).lnk", chain);
+ return GetSpecialFolderPath(CSIDL_STARTUP) / "Dogecoin (testnet).lnk";
+ return GetSpecialFolderPath(CSIDL_STARTUP) / strprintf("Dogecoin (%s).lnk", chain);
}
bool GetStartOnSystemStartup()
@@ -741,9 +741,9 @@ bool SetStartOnSystemStartup(bool fAutoStart)
optionFile << "[Desktop Entry]\n";
optionFile << "Type=Application\n";
if (chain == CBaseChainParams::MAIN)
- optionFile << "Name=Bitcoin\n";
+ optionFile << "Name=Dogecoin\n";
else
- optionFile << strprintf("Name=Bitcoin (%s)\n", chain);
+ optionFile << strprintf("Name=Dogecoin (%s)\n", chain);
optionFile << "Exec=" << pszExePath << strprintf(" -min -testnet=%d -regtest=%d\n", GetBoolArg("-testnet", false), GetBoolArg("-regtest", false));
optionFile << "Terminal=false\n";
optionFile << "Hidden=false\n";
@@ -204,13 +204,13 @@ bool parseBitcoinURI(const QUrl &uri, SendCoinsRecipient *out)
bool parseBitcoinURI(QString uri, SendCoinsRecipient *out)
{
- // Convert bitcoin:// to bitcoin:
+ // Convert dogecoin:// to dogecoin:
//
@@ -204,13 +204,13 @@ bool parseBitcoinURI(const QUrl &uri, SendCoinsRecipient *out)
//
- // Cannot handle this later, because bitcoin:// will cause Qt to see the part after // as host,
+ // Cannot handle this later, because dogecoin:// will cause Qt to see the part after // as host,
// which will lower-case it (and thus invalidate the address).